@@ -8,9 +8,9 @@ use Log::ger;
 use Perinci::Object;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-09-28'; # DATE
+our $DATE = '2026-02-02'; # DATE
 our $DIST = 'App-PDFUtils'; # DIST
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 our %SPEC;
 
@@ -124,7 +124,11 @@ sub add_pdf_password {
         }
         # XXX test that tempfile doesn't yet exist. but actually we can't avoid
         # race condition because qpdf is another process
-        my $tempf = "$f.tmp" . int(rand()*900_000 + 100_000);
+        (my $tempf = $f) =~ s/\.pdf$/".tmp_" . int(rand()*900_000 + 100_000) . ".pdf"/ei
+            or do {
+                $envres->add_result(412, "Cannot set temporary name for $f");
+                next FILE;
+            };
 
         my $decrypted;
         my ($stdout, $stderr);
@@ -228,7 +232,11 @@ sub remove_pdf_password {
         }
         # XXX test that tempfile doesn't yet exist. but actually we can't avoid
         # race condition because qpdf is another process
-        my $tempf = "$f.tmp" . int(rand()*900_000 + 100_000);
+        (my $tempf = $f) =~ s/\.pdf$/".tmp_" . int(rand()*900_000 + 100_000) . ".pdf"/ei
+            or do {
+                $envres->add_result(412, "Cannot set temporary name for $f");
+                next FILE;
+            };
 
         my $decrypted;
       PASSWORD:
@@ -544,7 +552,7 @@ App::PDFUtils - Command-line utilities related to PDF files
 
 =head1 VERSION
 
-This document describes version 0.016 of App::PDFUtils (from Perl distribution App-PDFUtils), released on 2024-09-28.
+This document describes version 0.017 of App::PDFUtils (from Perl distribution App-PDFUtils), released on 2026-02-02.
 
 =head1 SYNOPSIS
 
@@ -895,7 +903,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2024, 2023, 2022, 2021, 2020, 2017 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2026 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
